# CAT Bridge: A Versatile Tool for Multi-Omics Analysis

## Overview
CAT Bridge (Compounds And Transcripts Bridge) is a robust tool built with the goal of **uncovering biosynthetic mechanisms in multi-omics data**, such as identifying genes potentially involved in compound synthesis by incorporating metabolomics and transcriptomics data.

One of the key features of CAT Bridge is its custom-built design for **handling multi-mics time series data** - a niche that has seen a dearth of dedicated tools till now. 

And CAT Bridge is **integrated with GPT 3.5 Turbo** integration to help users dive deeper into the complex biological mechanisms at play.

**Visualisation** is key to understanding complex data. That's why CAT Bridge also includes a comprehensive suite of visualization capabilities to help you understand, explore, and present your findings more intuitively and effectively.

At the heart of CAT Bridge lies a data-driven algorithm, theoretically enabling its application across a wide spectrum of multi-omics data showcasing causal relationships. However, so far, we've tested this only between metabolome-transcriptome and metabolome-metabolome interactions.

## Installation
Python dependencies can be installed using pip (from the Unix terminal)
```pip install catbridge```

## Contact
The package is developed and maintained by Bowen Yang (by8@ualberta.ca). Please, reach us for problems, comments or suggestions.


